@@ -26,6 +26,7 @@
 #include "customfieldmanager_p.h"
 #include "standardcontactformatter.h"
 #include "textbrowser_p.h"
+#include "helper_p.h"
 #include "editor/im/improtocols.h"
 #include <KIOCore/kio/transferjob.h>
 #include <collection.h>
@@ -54,8 +55,8 @@ class Q_DECL_HIDDEN ContactViewer::Private
 public:
     Private(ContactViewer *parent)
         : mParent(parent)
-        , mBrowser(Q_NULLPTR)
-        , mParentCollectionFetchJob(0)
+        , mBrowser(nullptr)
+        , mParentCollectionFetchJob(nullptr)
     {
         mStandardContactFormatter = new StandardContactFormatter;
         mContactFormatter = mStandardContactFormatter;
@@ -170,11 +171,11 @@ public:
         QVector<QVariantMap> customFieldDescriptions;
         const CustomField::List globalCustomFields = CustomFieldManager::globalCustomFieldDescriptions();
         customFieldDescriptions.reserve(localCustomFieldDescriptions.count() + globalCustomFields.count());
-        foreach (const QVariant &entry, localCustomFieldDescriptions) {
+        for (const QVariant &entry : qAsConst(localCustomFieldDescriptions)) {
             customFieldDescriptions << entry.toMap();
         }
 
-        foreach (const CustomField &field, globalCustomFields) {
+        for (const CustomField &field : qAsConst(globalCustomFields)) {
             QVariantMap description;
             description.insert(QStringLiteral("key"), field.key());
             description.insert(QStringLiteral("title"), field.title());
@@ -243,7 +244,7 @@ public:
 
     void slotParentCollectionFetched(KJob *job)
     {
-        mParentCollectionFetchJob = 0;
+        mParentCollectionFetchJob = nullptr;
 
         QString addressBookName;
 
@@ -313,12 +314,12 @@ KContacts::Addressee ContactViewer::rawContact() const
 
 void ContactViewer::setContactFormatter(AbstractContactFormatter *formatter)
 {
-    if (formatter == 0) {
+    if (formatter == nullptr) {
         d->mContactFormatter = d->mStandardContactFormatter;
     } else {
         d->mContactFormatter = formatter;
         delete d->mStandardContactFormatter;
-        d->mStandardContactFormatter = 0;
+        d->mStandardContactFormatter = nullptr;
     }
 }
 
@@ -347,7 +348,7 @@ void ContactViewer::itemChanged(const Item &contactItem)
     if (d->mParentCollectionFetchJob) {
         disconnect(d->mParentCollectionFetchJob, SIGNAL(result(KJob*)), this, SLOT(slotParentCollectionFetched(KJob*)));
         delete d->mParentCollectionFetchJob;
-        d->mParentCollectionFetchJob = 0;
+        d->mParentCollectionFetchJob = nullptr;
     }
 
     d->mParentCollectionFetchJob = new CollectionFetchJob(contactItem.parentCollection(), CollectionFetchJob::Base, this);
