@@ -2,7 +2,7 @@
     This file is part of Akonadi Contact.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2017 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -29,7 +29,7 @@ class CustomFieldEditorWidgetTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit CustomFieldEditorWidgetTest(QObject *parent = Q_NULLPTR);
+    explicit CustomFieldEditorWidgetTest(QObject *parent = nullptr);
     ~CustomFieldEditorWidgetTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
