@@ -20,6 +20,7 @@
 */
 
 #include "displaynameeditwidget.h"
+#include "helper_p.h"
 
 #include <QtCore/QEvent>
 #include <QAbstractItemView>
@@ -31,7 +32,6 @@
 #include <KComboBox>
 #include <KLocalizedString>
 
-
 // Tries to guess the display type that is used for the passed contact
 static DisplayNameEditWidget::DisplayType guessedDisplayType(const KContacts::Addressee &contact)
 {
@@ -54,7 +54,7 @@ class DisplayNameDelegate : public QStyledItemDelegate
 {
     Q_OBJECT
 public:
-    DisplayNameDelegate(QAbstractItemView *view, QObject *parent = Q_NULLPTR)
+    DisplayNameDelegate(QAbstractItemView *view, QObject *parent = nullptr)
         : QStyledItemDelegate(parent)
         , mMaxDescriptionWidth(0)
     {
@@ -68,7 +68,7 @@ public:
         QFont font = view->font();
         font.setStyle(QFont::StyleItalic);
         QFontMetrics metrics(font);
-        foreach (const QString &description, mDescriptions) {
+        for (const QString &description : qAsConst(mDescriptions)) {
             mMaxDescriptionWidth = qMax(mMaxDescriptionWidth, metrics.width(description));
         }
 
